@@ -2,8 +2,19 @@ import argparse
 from todocom.tokenize import tokenize
 from todocom.utils import get_files, print_todos, save_todos
 
+WHITE = "\033[0m"
+YELLOW = "\033[33m"
+
+
+def cli_tool():
+    """
+    Define arguments for "todo" command (cli) using argparse package.
+
+    Return:
+    ------------
+    argparse.ArgumentParser Object
+    """
 
-def main():
     # create a parser object
     parser = argparse.ArgumentParser(description = "Read directories")
 
@@ -27,13 +38,30 @@ def main():
         action="store_true",
         help=("Retrieve 'soon' TODO comments. "))
 
+    # Output file argument
     parser.add_argument(
         "-o", "--output",
         nargs = "?",
         dest = "out",
-        const='./todo.txt',
-        default= None,
-        help=("Save comments in an external file"))
+        const = './todo.txt',
+        default = None,
+        help = ("Save comments in an external file"))
+
+    # Assigned argument
+    parser.add_argument(
+        "-a", "--assigned",
+        nargs = 1,
+        metavar = "assigned_to",
+        type = str,
+        default = None,
+        help = "Find all TODOs that were assigned to a specific user")
+
+    return parser
+
+
+def main():
+
+    parser = cli_tool()
 
     # parse the arguments from standard input
     args = parser.parse_args()
@@ -44,19 +72,30 @@ def main():
     soon_todos = []
     todos = []
     for file in _:
-        # Todo soon: Add try-catch for UnicodeDecodeError: 'utf-8' codec can't decode byte 0x8b in position 1: invalid start byte  # noqa: E501
         with open(file, "r") as f:
-            for token in tokenize(f.read(), file, urgent = args.urgent, soon = args.soon):
+            try:
+                content = f.read()
+            except UnicodeDecodeError:
+                print(f"{YELLOW}**** Warning: Couldn't read file {file} **** \n{WHITE}")
+                continue
 
-                if args.out:
-                    todos.append(token)
+        # Tokenize file and iterate over tokens
+        for token in tokenize(content,
+                              file,
+                              urgent = args.urgent,
+                              soon = args.soon,
+                              assigned = args.assigned):
+
+            # Ensure tokens are put in the correct list
+            if args.out:
+                todos.append(token)
+            else:
+                if "urgent" in token.re_type:
+                    urgent_todos.append(token)
+                elif "soon" in token.re_type:
+                    soon_todos.append(token)
                 else:
-                    if "urgent" in token.re_type:
-                        urgent_todos.append(token)
-                    elif "soon" in token.re_type:
-                        soon_todos.append(token)
-                    else:
-                        reg_todos.append(token)
+                    reg_todos.append(token)
 
     if args.out:
         # Store results in a txt file
